==> BioFTF_1.1-0.tar.gz: BioFTF/man/ranking.Rd <==
\name{ranking}
\alias{ranking}
\title{Compute the communities ranking according to the biodiversity computed using the functional tools.}
\usage{ranking(x,n)}


\arguments{

\item{x}{A data matrix with the abundance of the species (the rows are the communities and the columns indicate the species living in a community). The user can freely choose to use the absolute or relative frequencies.}

\item{n}{The number of points of the domain [-1,1] that the user wants to consider in computing the functional tools. It is suggested to choose a number in the interval [3,10000] because a value of less than 3 has little sense; indeed, the major indices of biodiversity are the richness index, the index of Shannon and the index of Simpson (that we get for beta equal to -1, 0, +1, respectively). On the other hand, a value greater than 10000 is not very interesting because with a value of approximately 100 we already have a good approximation. The examples provided in this package always divide the domain into 20 intervals. The default value is n=20, thus it is also possible to omit the value of n.}



}


\description{
This function provides the communities ranking according to the biodiversity computed using the functional tools.
Specifically, if communities present the same number of species then we can refer to the arc length. The arc length is a useful tool to establish a ranking among communities with intersecting profiles and the same number of species. It represents the length of a curve if it were rectified; it is a scalar measure extremely high in case of maximum dominance, whereas it decreases in case of high evenness. Unlike the classical indices, it considers each point of the domain corresponding to a different biodiversity value. For this reason, the arc length provides a ranking rule for communities with intersecting profiles, making possible to order them without the use of graphs. 
However, if communities do not present the same number of species then we must refer to the area. In an ecological framework, the area under the profiles can be used to assess biodiversity because it can rank communities, even if they have different number of species. Indeed, in a case of maximum dominance, the area is extremely low; while in a case of evenness, it increase. The main advantage of using area is that the ordering among communities can be investigated without the analysis of a graph. It provides a scalar measure of biodiversity considering the whole domain. This is not possible with the classical indices.





}
\author{
Fabrizio Maturo, Francesca Fortuna, Tonio Di Battista
}

\source{
ENVIRONMENTAL MONITORING THROUGH FUNCTIONAL BIODIVERSITY TOOLS - T. Di Battista, F. Fortuna, F. Maturo - Ecological Indicators (2016) 60, 237-247 - online (2015). DOI: 10.1016/j.ecolind.2015.05.056.

PARAMETRIC FUNCTIONAL ANALYSIS OF VARIANCE FOR FISH BIODIVERSITY ASSESSMENT - T. Di Battista, F. Fortuna, F. Maturo - Journal of Environmental Informatics. Special issue of Marine and Freshwater Environmental Engineering and Management, Journal of Environmental Informatics. In press.

}
\examples{
x=matrix(c(0.3,0.5,0.1,0.05,0.05,0.25,0.25,0.25,0.25,0,0.35,0.3,0.35,0,0),3,5)
ranking(x,20)
}

==> BioFTF_1.2-0.tar.gz: BioFTF/man/ranking.Rd <==
\name{ranking}
\alias{ranking}
\title{Compute the communities ranking according to the biodiversity computed using the functional tools.}
\usage{ranking(x,n)}


\arguments{

\item{x}{A data matrix with the abundance of the species (the rows are the communities and the columns indicate the species living in a community). The user can freely choose to use the absolute or relative frequencies.}

\item{n}{The number of points of the domain [-1,1] that the user wants to consider in computing the functional tools. It is suggested to choose a number in the interval [3,10000] because a value of less than 3 has little sense; indeed, the major indices of biodiversity are the richness index, the index of Shannon and the index of Simpson (that we get for beta equal to -1, 0, +1, respectively). On the other hand, a value greater than 10000 is not very interesting because with a value of approximately 100 we already have a good approximation. The examples provided in this package always divide the domain into 20 intervals. The default value is n=20.}



}


\description{
This function provides the communities ranking according to the biodiversity computed using the functional tools.
Specifically, if communities present the same number of species then we can refer to the arc length. The arc length is a useful tool to establish a ranking among communities with intersecting profiles and the same number of species. It represents the length of a curve if it were rectified; it is a scalar measure extremely high in case of maximum dominance, whereas it decreases in case of high evenness. Unlike the classical indices, it considers each point of the domain corresponding to a different biodiversity value. For this reason, the arc length provides a ranking rule for communities with intersecting profiles, making possible to order them without the use of graphs. 
However, if communities do not present the same number of species then we must refer to the area. In an ecological framework, the area under the profiles can be used to assess biodiversity because it can rank communities, even if they have different number of species. Indeed, in a case of maximum dominance, the area is extremely low; while in a case of evenness, it increase. The main advantage of using area is that the ordering among communities can be investigated without the analysis of a graph. It provides a scalar measure of biodiversity considering the whole domain. This is not possible with the classical indices.





}
\author{
Fabrizio Maturo, Francesca Fortuna, Tonio Di Battista
}

\source{
ENVIRONMENTAL MONITORING THROUGH FUNCTIONAL BIODIVERSITY TOOLS - T. Di Battista, F. Fortuna, F. Maturo - Ecological Indicators (2016) 60, 237-247 - online (2015). DOI: 10.1016/j.ecolind.2015.05.056.

PARAMETRIC FUNCTIONAL ANALYSIS OF VARIANCE FOR FISH BIODIVERSITY ASSESSMENT - T. Di Battista, F. Fortuna, F. Maturo - Journal of Environmental Informatics. Special issue of Marine and Freshwater Environmental Engineering and Management, Journal of Environmental Informatics. In press.

}
\examples{
x=matrix(c(0.3,0.5,0.1,0.05,0.05,0.25,0.25,0.25,0.25,0,0.35,0.3,0.35,0,0),3,5)
ranking(x,20)
}
